from django.conf import settings

USER_CATEGORIES_REQUIRING_RESET = getattr(
    settings, "RESETTY_USER_CATEGORIES_REQUIRING_RESET", ["is_staff"]
)
RESET_PASSWORD_DELTA_DAYS = getattr(settings, "RESETTY_RESET_PASSWORD_DELTA_DAYS", 90)
RESET_PASSWORD_URL = getattr(settings, "RESETTY_RESET_PASSWORD_URL", None)
REDIRECT_EXCLUDED_PATHS = getattr(settings, "RESETTY_REDIRECT_EXCLUDED_PATHS", [])
