# Generated by Django 2.2.11 on 2020-06-13 20:25

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("resetty", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(model_name="resetpasswordextra", name="id",),
        migrations.AlterField(
            model_name="resetpasswordextra",
            name="user",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE,
                primary_key=True,
                serialize=False,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
